summaryrefslogtreecommitdiff
path: root/example_create.sh
diff options
context:
space:
mode:
authorBenjamin Chausse <benjamin@chausse.xyz>2020-10-17 00:03:01 -0400
committerBenjamin Chausse <benjamin@chausse.xyz>2020-10-17 00:03:01 -0400
commit53c834d9b83c59e9d64f426f5359cf8e565befff (patch)
tree8e10db7656ac9cbdae76e66ff9686604512e3978 /example_create.sh
parent854bb3b66167ccd7e150a18557824f8992bbe25e (diff)
Initial Commit
Diffstat (limited to 'example_create.sh')
-rwxr-xr-xexample_create.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/example_create.sh b/example_create.sh
index e1b79f4..ab79327 100755
--- a/example_create.sh
+++ b/example_create.sh
@@ -3,7 +3,7 @@
# - Makes static pages for each repository directory.
#
# NOTE, things to do manually (once) before running this script:
# - copy style.css, logo.svg and favicon.ico manually, a style.css example
# is included.
#
# - write clone url, for example "git://git.codemadness.org/dir" to the "url"
@@ -24,8 +24,8 @@ mkdir -p "$webdir" || exit 1
# set assets if not already there
ln -s "$defaultdir/style.css" "$webdir/style.css" 2> /dev/null
-ln -s "$defaultdir/logo.svg" "$webdir/logo.svg" 2> /dev/null
-ln -s "$defaultdir/favicon.ico" "$webdir/favicon.ico" 2> /dev/null
+ln -s "$defaultdir/logo.png" "$webdir/logo.png" 2> /dev/null
+ln -s "$defaultdir/favicon.png" "$webdir/favicon.png" 2> /dev/null
# clean
for dir in "$webdir/"*/; do
@@ -3,7 +3,7 @@
#
# NOTE, things to do manually (once) before running this script:
-# - copy style.css, logo.svg and favicon.ico manually, a style.css example
+# - copy style.css, logo.png and favicon.png manually, a style.css example
# is included.
#